import React, { useCallback, useContext } from 'react';
import { Menu } from 'antd';
import { useRouter } from 'next/router';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { LoggedUserContext } from '../../contexts/LoggedUserContext';
import {
    faUser,
    faFileExport,
    faFileLines,
    faUsers,
    faTags,
    faBookmark,
} from '@fortawesome/free-solid-svg-icons';

const UserNavBar = () => {
    const router = useRouter();
    const { logout } = useContext(LoggedUserContext);
    const { SubMenu } = Menu;

    const handleLogout = useCallback(() => {
        logout();
        router.push('/login');
    }, [logout, router]);

    return (
        <Menu theme="dark" mode="horizontal">
            <Menu.Item style={{}} key="1" onClick={() => router.push('/documents/admin')}>
                <FontAwesomeIcon icon={faFileLines} /> Dokumenty
            </Menu.Item>
            <Menu.Item style={{}} key="2" onClick={() => router.push('/users')}>
                <FontAwesomeIcon icon={faUsers} /> Uživatelé
            </Menu.Item>
            <Menu.Item style={{}} key="3" onClick={() => router.push('/tags')}>
                <FontAwesomeIcon icon={faTags} /> Značky
            </Menu.Item>
            <Menu.Item style={{}} key="4" onClick={() => router.push('/classes')}>
                <FontAwesomeIcon icon={faBookmark} /> Třídy
            </Menu.Item>
            <Menu.Item style={{}} key="5" onClick={() => router.push('/export')}>
                <FontAwesomeIcon icon={faFileExport} /> Export
            </Menu.Item>

            <SubMenu
                icon={<FontAwesomeIcon icon={faUser} />}
                key="account"
                title={'Admin XY'} // TODO show username
            >
                <Menu.Item key="setting:2" onClick={() => handleLogout()}>
                    Odhlásit se
                </Menu.Item>
            </SubMenu>
        </Menu>
    );
};

export default UserNavBar;
